@@ -51,3 +51,23 @@ positions_corrector <- function(positions, group_header_rows, n_row) {
   adjust_numbers <- pc_matrix$adj[pc_matrix$old_id %in% positions]
   return(adjust_numbers + positions)
 }
+
+latex_row_cells <- function(x) {
+  strsplit(x, " \\& ")
+}
+
+regex_escape <- function(x, double_backslash = FALSE) {
+  if (double_backslash) {
+    x <- gsub("\\\\", "\\\\\\\\", x)
+  }
+  x <- gsub("\\$", "\\\\\\$", x)
+  x <- gsub("\\(", "\\\\(", x)
+  x <- gsub("\\)", "\\\\)", x)
+  x <- gsub("\\[", "\\\\]", x)
+  x <- gsub("\\[", "\\\\]", x)
+  x <- gsub("\\{", "\\\\{", x)
+  x <- gsub("\\}", "\\\\}", x)
+  x <- gsub("\\*", "\\\\*", x)
+  return(x)
+}
+
